# Adamlibrary Project

My **Adamlibrary** project, which I developed to bring low-level operations in basic C functions to Python, now you can use low-level C functions directly from Python.

## Windows Support
- ✅ Low-level memory management and manipulation
- ✅ Mathematical calculations and analysis
- ✅ Stringer option extended detailed string
- ❌ Graphics-based memory and window management
- ✅ Data structure management

## Support for UNIX POSIX Compliant Devices
- ✅ Low-level memory management and manipulation
- ✅ Mathematical calculations and analysis
- ✅ Stringer option extended detailed string
- ❌ Graphics-based buffer management unit
- ✅ Data structure management

Support for DOS-based systems will be available in future versions.
## Used Python-pip
```bash
pip install adamlibrary
```
## Dependencies
- GCC
- ctypes
- util-linux
- Win32 system architecture libraries

[Our Github Page](https://github.com/Zamanhuseyinli/Adam-cpython)

## Community Site
Visit our community site: [Azccriminal](https://azccriminal.space)

If you want to support us: Donate via [PayPal](https://www.paypal.com/donate/?hosted_button_id=NKPHAU3NY3GZU)
